Change Log
==========

..
   All enhancements and patches to federated_content_connector will be documented
   in this file.  It adheres to the structure of https://keepachangelog.com/ ,
   but in reStructuredText instead of Markdown (for ease of incorporation into
   Sphinx documentation and the PyPI description).

   This project adheres to Semantic Versioning (https://semver.org/).

.. There should always be an "Unreleased" section for changes pending release.

Unreleased
----------

1.2.1 – 2023-08-03
------------------
* feat: hook for modify course enrollment data

1.2.0 – 2023-07-18
------------------
* Refactor `import_course_runs_metadata` command to import all courseruns

1.1.0 – 2023-06-21
------------------
* Management command to refresh CourseDetails data

1.0.3 – 2023-06-15
------------------
* backfill all data

1.0.2 – 2023-06-15
------------------
* Handle empty courserun seats.
* Add limit query param in api call

1.0.1 – 2023-06-14
------------------
* Update courserun seat sorting logic.

1.0.0 – 2023-06-06
------------------
* Fetch course metadata from discovery and store.

0.2.1 – 2023-06-5
------------------
* Fixed issue with product source data type

0.2.0 – 2023-05-31
------------------
* Added support for stage and prod landing pages via settings

0.1.1 – 2023-05-26
------------------
* Fixes for PyPI description markup.

0.1.0 – 2023-05-26
------------------
* Basic skeleton of the app.
* CreateCustomUrlForCourseStep pipeline.
* First release on PyPI.
